@@ -8,7 +8,7 @@ Locale::CLDR - A Module to create locale objects with localisation data from the
 
 =head1 VERSION
 
-Version 0.25.5
+Version 0.26.6
 
 =head1 SYNOPSIS
 
@@ -19,27 +19,27 @@ few parts of the code that require version 5.18 or above.
 
 =head1 USAGE
 
- my $locale = Locale::CLDR->new('en_GB');
+ my $locale = Locale::CLDR->new('en_US');
 
 or
 
- my $locale = Locale::CLDR->new(language_id => 'en', territory_id => 'gb');
+ my $locale = Locale::CLDR->new(language_id => 'en', territory_id => 'us');
  
 A full locale identifier is
  
 C<language>_C<script>_C<territory>_C<variant>_u_C<extension name>_C<extension value>
  
- my $locale = Locale::CLDR->new('en_latn_GB_SCOUSE_u_nu_traditional');
+ my $locale = Locale::CLDR->new('en_latn_US_SCOUSE_u_nu_traditional');
  
 or
  
- my $locale = Locale::CLDR->new(language_id => 'en', script_id => 'latn', territory_id => 'gb', variant => 'SCOUSE', extensions => { nu => 'traditional' } );
+ my $locale = Locale::CLDR->new(language_id => 'en', script_id => 'latn', territory_id => 'US', variant => 'SCOUSE', extensions => { nu => 'traditional' } );
  
 =cut
 
 use v5.10;
 use version;
-our $VERSION = version->declare('v0.25.5');
+our $VERSION = version->declare('v0.26.6');
 
 use open ':encoding(utf8)';
 use utf8;
@@ -58,7 +58,7 @@ use List::Util qw(first);
 use Class::MOP;
 use DateTime::Locale;
 use Unicode::Normalize();
-use Locale::CLDR::Collator();
+#use Locale::CLDR::Collator();
 use File::Spec();
 
 # Backwards compatibility
@@ -67,26 +67,8 @@ BEGIN {
 		*fc = \&CORE::fc;
 	}
 	else {
-		# This code taken from Unicode::CaseFold by Andrew Rodland
-		require Unicode::UCD;
-		*fc = sub {
-			my ($string) = @_;
-			
-			my $out = "";
-
-			for my $codepoint (unpack "U*", $string) {
-				my $mapping = Unicode::UCD::casefold($codepoint);
-				my @cp;
-				if (!defined $mapping) {
-					@cp = ($codepoint);
-				} else {
-					@cp = map hex, split / /, $mapping->{'full'};
-				}
-				$out .= pack "U*", @cp;
-			}
-
-			return $out;
-		};
+		# We only use fc() with code that expects Perl v5.18 or above
+		*fc = sub {};
 	}
 }
 
@@ -650,14 +632,14 @@ sub _build_module {
 	# Note the order we push these onto the stack is important
 	@path = join '::', @likely_path;
 	push @path, join '::', $likely_path[0], 'Any', $likely_path[2];
-	push @path, join '::', @likely_path[0 .. 1], 'Any';
-	push @path, join '::', $likely_path[0], 'Any', 'Any';
+	push @path, join '::', @likely_path[0 .. 1];
+	push @path, join '::', $likely_path[0];
 	
 	# Now we go through the path loading each module
 	# And calling new on it. 
 	my $module;
 	foreach my $module_name (@path) {
-		$module_name = "Locale::CLDR::$module_name";
+		$module_name = "Locale::CLDR::Locales::$module_name";
 		eval { Class::Load::load_class($module_name); };
 		next if $@;
 		$module = $module_name->new;
@@ -667,9 +649,10 @@ sub _build_module {
 	# If we only have the root module then we have a problem as
 	# none of the language specific data is in the root. So we
 	# fall back to the en module
-	if (! $module || ref $module eq 'Locale::CLDR::Root') {
-		Class::Load::load_class('Locale::CLDR::En');
-		$module = Locale::CLDR::En->new
+
+	if ( ref $module eq 'Locale::CLDR::Locales::Root') {
+		Class::Load::load_class('Locale::CLDR::Locales::En');
+		$module = Locale::CLDR::Locales::En->new
 	}
 
 	return $module;
@@ -960,7 +943,7 @@ foreach my $property (qw(
 =item date_format_medium 
 
 =item date_format_short
-	
+
 =item time_format_full
 
 =item time_format_long
@@ -968,11 +951,11 @@ foreach my $property (qw(
 =item time_format_medium
 
 =item time_format_short
-	
+
 =item datetime_format_full
 
 =item datetime_format_long
-	
+
 =item datetime_format_medium
 
 =item datetime_format_short
@@ -1065,7 +1048,7 @@ the locale's language and script
 
 =item format_for($date_time_format)
 
-This method takes a CLDR datetime format and returns
+This method takes a CLDR date time format and returns
 the localised version of the format.
 
 =cut
@@ -1179,13 +1162,13 @@ sub BUILDARGS {
 		foreach ($language, $script, $territory, $variant) {
 			$_ = '' unless defined $_;
 		}
-			
+
 		%args = (
-			language_id	=> $language,
+			language_id		=> $language,
 			script_id		=> $script,
 			territory_id	=> $territory,
 			variant_id		=> $variant,
-			extensions	=> $extensions,
+			extensions		=> $extensions,
 		);
 	}
 
@@ -1488,7 +1471,7 @@ sub locale_name {
 		return $display_name if defined $display_name;
 	}
 
-	# $name can be a string or a Locale::CLDR::*
+	# $name can be a string or a Locale::CLDR::Locales::*
 	if (! ref $name) {
 		$name = Locale::CLDR->new($name);
 	}
@@ -2104,7 +2087,7 @@ sub is_exemplar_character {
 =item index_characters()
 
 Returns an array ref of characters normally used when creating 
-an index and ordered appropriatly.
+an index and ordered appropriately.
 
 =cut
 
@@ -2462,8 +2445,8 @@ sub _unit_compound {
 	my @bundles = $self->_find_bundle('units');
 	my $format;
 	foreach my $bundle (@bundles) {
-		if (exists $bundle->units()->{$type}{per}{''}) {
-			$format = $bundle->units()->{$type}{per}{''};
+		if (exists $bundle->units()->{$type}{per}{1}) {
+			$format = $bundle->units()->{$type}{per}{1};
 			last;
 		}
 	}
@@ -2475,8 +2458,8 @@ sub _unit_compound {
 		foreach my $alias (@aliases) {
 			$type = $alias->unit_alias()->{$original_type};
 			foreach my $bundle (@bundles) {
-				if (exists $bundle->units()->{$type}{per}{''}) {
-					$format = $bundle->units()->{$type}{per}{''};
+				if (exists $bundle->units()->{$type}{per}{1}) {
+					$format = $bundle->units()->{$type}{per}{1};
 					last;
 				}
 			}
@@ -2557,7 +2540,8 @@ sub is_no {
 
 =head2 Transliteration
 
-This method requires Perl version 5.18 or above to use
+This method requires Perl version 5.18 or above to use and for you to have
+installed the optional C<Bundle::CLDR::Transformations>
 
 =over 4
 
@@ -2672,7 +2656,7 @@ sub _transformation_transform {
 		}
 	}
 	return $text;
-}		
+}
 
 sub _transform_convert {
 	my ($self, $text, $rules) = @_;
@@ -2723,7 +2707,8 @@ sub list {
 	
 	my %list_data;
 	foreach my $bundle (reverse @bundles) {
-		%list_data = %{$bundle->listPatterns};
+		my %listPatterns = %{$bundle->listPatterns};
+		@list_data{keys %listPatterns} = values %listPatterns;
 	}
 	
 	if (my $pattern = $list_data{scalar @data}) {
@@ -3154,7 +3139,8 @@ sub _build_any_era {
 						
 			my $result = $eras->{$default_calendar}{$width};
 			
-			my @result = map {$result->{$_}} sort { $a <=> $b } keys %$result;
+			my @result;
+			@result[keys %$result] = values %$result;
 			
 			return \@result if keys %$result;
 		}
@@ -3651,7 +3637,7 @@ This method returns a hash that maps valid variant codes to their valid aliases
 =head2 Information about weeks
 
 There are no standard codes for the days of the weeks so CLDR uses the following
-three tetter codes to represent unlocalised days
+three letter codes to represent unlocalised days
 
 =over 4
 
@@ -3817,7 +3803,7 @@ releases.
 $for_cash is only used during currency formatting. If true then cash rounding
 will be used otherwise financial rounding will be used. 
 
-This function also handles rule based number formatting. If $format is string equivilant
+This function also handles rule based number formatting. If $format is string equivalent
 to one of the current locale's public rule based number formats then $number will be 
 formatted according to that rule. 
 
@@ -3991,6 +3977,8 @@ used the territory of the current locale.
 
 =back
 
+=begin comment
+
 =head2 Collation
 
 =over 4
@@ -4002,8 +3990,12 @@ try and match the API from L<Unicode::Collate> as much as possible and add tailo
 
 =back
 
+=end comment
+
 =cut
 
+=begin comment
+
 sub collation {
 	my ($self, %params) = @_;
 	
@@ -4040,6 +4032,14 @@ sub _default_collation_strength {
 	return 3;
 }
 
+=end comment
+
+=head1 Locales
+
+Other locales can be found on CPAN. You can install Language packs from the 
+Locale::CLDR::Locales::* packages. You can also install language packs for
+a given territory by looking for a Bundle::Locale::CLDR::* package
+
 =head1 AUTHOR
 
 John Imrie, C<< <john dot imrie1 at gmail dot com> >>
@@ -4086,11 +4086,6 @@ Everyone at the Unicode Consortium for providing the data.
 Karl Williams for his tireless work on Unicode in the Perl 
 regex engine.
 
-Andrew Rodland for his L<Unicode::CaseFold> module that I
-pinched the fc() code from for early versions of Perl that
-don't have this function.
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009-2014 John Imrie.
